@@ -78,6 +78,19 @@ class RecordDraftService(RecordService):
         return self.result_item(
             self, identity, draft, links_config=links_config)
 
+    def read_latest(self, id_, identity, links_config=None):
+        """Retrieve latest record."""
+        # Resolve and require permission
+        record = self.record_cls.pid.resolve(id_)
+        self.require_permission(identity, "read", record=record)
+
+        # Retrieve latest if record is not
+        if not record.versions.is_latest:
+            record = self.record_cls.get_record(record.versions.latest_id)
+
+        return self.result_item(
+            self, identity, record, links_config=links_config)
+
     def update_draft(self, id_, identity, data, links_config=None,
                      revision_id=None):
         """Replace a draft."""
@@ -325,6 +338,20 @@ class RecordDraftService(RecordService):
 
         return True
 
+    def rebuild_index(self, identity):
+        """Reindex all records and drafts.
+
+        Note: Skips (soft) deleted records and drafts.
+        """
+        ret_val = super().rebuild_index(identity)
+
+        for draft_meta in self.draft_cls.model_cls.query.all():
+            draft = self.draft_cls(draft_meta.data, model=draft_meta)
+            if not draft.is_deleted:
+                self.indexer.index(draft)
+
+        return ret_val
+
     def _validate_draft(self, identity, draft):
         """Validate a draft.
 
