@@ -4,7 +4,7 @@ from invenio_db import db
 from invenio_records.models import RecordMetadataBase
 
 from invenio_drafts_resources.records import DraftMetadataBase, \
-    ParentRecordMixin
+    ParentRecordMixin, ParentRecordStateMixin
 
 
 class ParentRecordMetadata(db.Model, RecordMetadataBase):
@@ -13,15 +13,23 @@ class ParentRecordMetadata(db.Model, RecordMetadataBase):
     __tablename__ = 'parent_mock_metadata'
 
 
-class DraftMetadata(db.Model, DraftMetadataBase,
-                    ParentRecordMixin(ParentRecordMetadata)):
+class DraftMetadata(db.Model, DraftMetadataBase, ParentRecordMixin):
     """Model for mock module metadata."""
 
     __tablename__ = 'draft_mock_metadata'
+    __parent_record_model__ = ParentRecordMetadata
 
 
-class RecordMetadata(db.Model, RecordMetadataBase,
-                     ParentRecordMixin(ParentRecordMetadata)):
+class RecordMetadata(db.Model, RecordMetadataBase, ParentRecordMixin):
     """Model for mock module metadata."""
 
     __tablename__ = 'record_mock_metadata'
+    __parent_record_model__ = ParentRecordMetadata
+
+
+class ParentState(db.Model, ParentRecordStateMixin):
+    """Model for mock module for parent state."""
+
+    __parent_record_model__ = ParentRecordMetadata
+    __record_model__ = RecordMetadata
+    __draft_model__ = DraftMetadata
